checkSupplyMismatch method

  1. @override
Future<bool?> checkSupplyMismatch()
override

checkSupplyMismatch() asynchronously checks if there is a supply mismatch in the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).

Implementation

@override
Future<bool?> checkSupplyMismatch() async {
  bool? supplyMismatch = await methodChannel.invokeMethod<bool>(
    'checkSupplyMismatch',
  );
  return supplyMismatch;
}