cleanPrinthead method

  1. @override
Future<bool?> cleanPrinthead()
override

cleanPrinthead() asynchronously cleans the printhead of the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).

Implementation

@override
Future<bool?> cleanPrinthead() async {
  bool? cleaned = await methodChannel.invokeMethod<bool>('cleanPrinthead');
  return cleaned;
}