connectWithManualIP method

  1. @override
Future<bool?> connectWithManualIP(
  1. String ipAddress,
  2. String printerModel
)
override

connectWithManualIP() takes the ip address and model of a printer and attempts to connect the mobile device to the printer.

@param ipAddress is a string representing the ip address of the printer to connect to. @param printerModel is a string representing the model of the printer to connect to.

@returns a bool representing the connection result.

Implementation

@override
Future<bool?> connectWithManualIP(
  String ipAddress,
  String printerModel,
) async {
  var sendMap = <String, dynamic>{
    "ipAddress": ipAddress,
    "printerModel": printerModel,
  };
  bool? connected = await methodChannel.invokeMethod<bool>(
    'connectWithManualIP',
    sendMap,
  );
  return connected;
}