getAvailablePrinterUpdates method
getAvailablePrinterUpdates() returns a list of string representing all printer updates that occurred since the last time this method was called.
Implementation
@override
Future<List<String?>> getAvailablePrinterUpdates() async {
final List<dynamic>? printerUpdates = await methodChannel
.invokeMethod<List<dynamic>?>('getAvailablePrinterUpdates');
return printerUpdates?.cast<String?>() ?? [];
}