getIsSupplyDirectThermal method

  1. @override
Future<bool?> getIsSupplyDirectThermal()
override

getIsSupplyDirectThermal() returns a Boolean representing if the supply installed in the connected printer is direct thermal and will not have a separate ribbon.

Implementation

@override
Future<bool?> getIsSupplyDirectThermal() async {
  bool? isSupplyDirectThermal = await methodChannel.invokeMethod<bool>(
    'getIsSupplyDirectThermal',
  );
  return isSupplyDirectThermal;
}