getRibbonName method

  1. @override
Future<String?> getRibbonName()
override

getRibbonName() returns a String representing the ribbon installed in the printer (will return empty string if there is no ribbon). Only the M611 and M710 support ribbons.

Implementation

@override
Future<String?> getRibbonName() async {
  try {
    String? ribbonName = await methodChannel.invokeMethod<String>(
      'getRibbonName',
    );
    return ribbonName;
  } on PlatformException catch (e) {
    if (e.message?.contains('dataCorrupted') == true) {
      return "";
    }
    rethrow;
  }
}