printBitmapWithDimensions method

  1. @override
Future<bool?> printBitmapWithDimensions(
  1. double bitmapWidthInInches,
  2. double labelLengthInInches,
  3. int copies,
  4. bool cutAfterEachLabel,
  5. bool isCollated,
  6. bool printTrailer,
)
override

printBitmapWithDimensions() asynchronously sends a print job of the currently set template or bitmap image to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).

Implementation

@override
Future<bool?> printBitmapWithDimensions(
  double bitmapWidthInInches,
  double labelLengthInInches,
  int copies,
  bool cutAfterEachLabel,
  bool isCollated,
  bool printTrailer,
) async {
  var sendMap = <String, dynamic>{
    "bitmapWidthInInches": bitmapWidthInInches,
    "labelLengthInInches": labelLengthInInches,
    "copies": copies,
    "cutAfterEachLabel": cutAfterEachLabel,
    "isCollated": isCollated,
    "printTrailer": printTrailer,
  };
  bool? printed = await methodChannel.invokeMethod<bool>('print', sendMap);
  return printed;
}