printBitmapWithDimensionsAndRfid method

  1. @override
Future<bool?> printBitmapWithDimensionsAndRfid(
  1. double bitmapWidthInInches,
  2. double labelLengthInInches,
  3. List rfidOperations,
  4. int copies,
  5. String cutOption,
  6. bool isCollated,
  7. bool printTrailer,
)
override

printBitmapWithDimensionsAndRfid() asynchronously sends a print job of the currently set template or bitmap image with RFID operations to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).

Implementation

@override
Future<bool?> printBitmapWithDimensionsAndRfid(
  double bitmapWidthInInches,
  double labelLengthInInches,
  List<dynamic> rfidOperations,
  int copies,
  String cutOption,
  bool isCollated,
  bool printTrailer,
) async {
  var sendMap = <String, dynamic>{
    "bitmapWidthInInches": bitmapWidthInInches,
    "labelLengthInInches": labelLengthInInches,
    "rfidOperations": rfidOperations,
    "copies": copies,
    "cutOption": cutOption,
    "isCollated": isCollated,
    "printTrailer": printTrailer,
  };
  bool? printed = await methodChannel.invokeMethod<bool>(
    'printBitmapWithDimensionsAndRfid',
    sendMap,
  );
  return printed;
}