printWithRfid method

  1. @override
Future<bool?> printWithRfid(
  1. List rfidOperations,
  2. int copies,
  3. String cutOption,
  4. bool isCollated,
  5. bool printTrailer,
)
override

printWithRfid() asynchronously sends a print job with RFID operations to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).

Implementation

@override
Future<bool?> printWithRfid(
  List<dynamic> rfidOperations,
  int copies,
  String cutOption,
  bool isCollated,
  bool printTrailer,
) async {
  var sendMap = <String, dynamic>{
    "rfidOperations": rfidOperations,
    "copies": copies,
    "cutOption": cutOption,
    "isCollated": isCollated,
    "printTrailer": printTrailer,
  };
  bool? printed = await methodChannel.invokeMethod<bool>(
    'printWithRfid',
    sendMap,
  );
  return printed;
}