setAlignmentOffset method

  1. @override
Future<bool?> setAlignmentOffset(
  1. int offset
)
override

setAlignmentOffset() asynchronously sets the alignment offset of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).

Implementation

@override
Future<bool?> setAlignmentOffset(int offset) async {
  var sendMap = <String, dynamic>{"offset": offset};
  bool? setResult = await methodChannel.invokeMethod<bool>(
    'setAlignmentOffset',
    sendMap,
  );
  return setResult;
}