BradyFlutterPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BradyFlutterPluginPlatform
Implementers

Constructors

BradyFlutterPluginPlatform()
Constructs a BradyFlutterPluginPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkSupplyMismatch() → Future<bool?>
checkSupplyMismatch() asynchronously checks if there is a supply mismatch in the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
cleanPrinthead() → Future<bool?>
cleanPrinthead() asynchronously cleans the printhead of the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
connect(String? printer, bool? connectWithBluetooth) → Future<bool?>
connect() takes the name of a discovered printer and the protocol to connect over and attempts to connect the mobile device to the printer.
connectWithManualIP(String ipAddress, String printerModel) → Future<bool?>
connectWithManualIP() takes the ip address and model of a printer and attempts to connect the mobile device to the printer.
cutSupply() → Future<bool?>
cutSupply() asynchronously makes the connected printer perform a cut operation (this can be called right after feed() for testing purposes) and returns a Boolean value afterwards with the result of the cut operation (i.e. success or failure).
disconnect() → Future<bool?>
disconnect() asynchronously disconnects from the currently connected printer and returns a Boolean value afterwards with the result of the disconnect operation (i.e. success or failure).
disconnectWithoutForget() → Future<bool?>
disconnectWithoutForget() asynchronously disconnects from the currently connected printer and returns a Boolean value afterwards with the result of the disconnect operation (i.e. success or failure).
feedSupply() → Future<bool?>
feedSupply() asynchronously makes the connected printer print one empty label and returns a Boolean value afterwards with the result of the feed operation(i.e. success or failure).
forgetLastConnectedPrinter() → Future<void>
forgetLastConnectedPrinter() clears the value of "LastConnectedPrinterName internally preventing auto-connections.
getAlignmentOffset() → Future<int?>
getAlignmentOffset() returns an integer representing the alignment offset.
getAutomaticShutdownTime() → Future<int?>
getAutomaticShutdownTime() returns an integer representing the automatic shutdown time in minutes.
getAvailablePrinterUpdates() → Future<List<String?>>
getAvailablePrinterUpdates() returns a list of string representing all printer updates that occurred since the last time this method was called.
getAvailablePrintQualityModes() → Future<List<String>?>
getAvailablePrintQualityModes() returns a list of strings representing the available print quality modes.
getBatteryLevelPercentage() → Future<int?>
getBatteryLevelPercentage() returns a String representing the battery level percentage of the connected printer.
getBluetoothVersion() → Future<String?>
getBluetoothVersion() returns a String representing the bluetooth version of the connected printer.
getCleanPrintheadSuccessful() → Future<bool?>
getCleanPrintheadSuccessful() returns a boolean representing if the printhead was cleaned successfully.
getConnectionType() → Future<String?>
getConnectionType() returns a String representing the protocol that was used to connect to the printer.
getDotsPerInch() → Future<int?>
getDotsPerInch() returns an Integer representing the dots per inch metric of the connected printer.
getErrorSeverity() → Future<String?>
getErrorSeverity() returns a String representing the severity of the current error.
getFirmwareVersion() → Future<String?>
getFirmwareVersion() returns a String representing the firmware version of the connected printer.
getHaveOwnership() → Future<bool?>
getHaveOwnership() returns a Boolean representing the mobile device's ownership of a nearby M211.
getInkRemainingPercentage() → Future<int?>
getInkRemainingPercentage() returns an integer representing the percentage of ink remaining in the connected printer.
getIsAcConnected() → Future<bool?>
getIsAcConnected() returns a Boolean representing if the connect printer is charging.
getIsCleanPrintheadMaintenanceRecommended() → Future<bool?>
getIsCleanPrintheadMaintenanceRecommended() returns a boolean representing if cleaning the printhead is recommended.
getIsSupplyDirectThermal() → Future<bool?>
getIsSupplyDirectThermal() returns a Boolean representing if the supply installed in the connected printer is direct thermal and will not have a separate ribbon.
getIsSupplyPreSized() → Future<bool?>
getIsSupplyPreSized() returns a Boolean representing if the supply installed in the connected printer is pre-sized. If false, the supply is continuous.
getLabelLibraryVersion() → Future<String?>
getLabelLibraryVersion() returns a String representing the version of the label library.
getLastConnectedPrinterName() → Future<String?>
getLastConnectedPrinterName() returns a String representing the name of the last printer that the app connected to.
getMaintenanceStationErrorAway() → Future<bool?>
getMaintenanceStationErrorAway() returns a boolean representing if the maintenance station error is away.
getMaintenanceStationWarningAway() → Future<bool?>
getMaintenanceStationWarningAway() returns a boolean representing if the maintenance station warning is away.
getOutOfInkCmy() → Future<bool?>
getOutOfInkCmy() returns a boolean representing if the printer is out of CMY ink.
getPostPrintAccessoryType() → Future<String?>
getPostPrintAccessoryType returns a String representing the name of the post print accessory type. Currently, only the i7500 has these capabilities.
getPreview(int elementSize) → Future<String?>
getPreview(Int) takes an Integer that represents the width in screen pixels that the print preview should display as (on the UI).
getPrinterModel() → Future<String?>
getPrinterModel() returns a String representing the current connected printer's model.
getPrinterName() → Future<String?>
getPrinterName() returns a String representing the current connected printer's name.
getPrinters() → Future<List<Map<String, String>>>
getPrinters() returns a List of Maps representing the printer name and how it was discovered via the discovery scan. Items from this list will only be removed on subsequent launches of the app.
getPrinterStatus() → Future<String?>
getPrinterStatus() returns a String representing the current printer connection status.
getPrinterStatusMessage() → Future<String?>
getPrinterStatusMessage() returns a String representing the current printer connection status message.
getPrinterStatusMessageTitle() → Future<String?>
getPrinterStatusMessageTitle() returns a String representing the current printer connection status message title.
getPrinterStatusRemedyExplanationMessage() → Future<String?>
getPrinterStatusRemedyExplanationMessage() returns a String representing a solution to resolve the current printer error if there is one.
getPrintheadInstalled() → Future<bool?>
getPrintheadInstalled() returns a boolean representing if the printhead is installed.
getRibbonColor() → Future<Color?>
getRibbonColor() returns a Color object representing the color of the ribbon installed in the connected printer (will return black Color if there is no ribbon).
getRibbonName() → Future<String?>
getRibbonName() returns a String representing the ribbon installed in the printer (will return empty string if there is no ribbon). Only the M611 and M710 support ribbons.
getRibbonRemainingPercentage() → Future<int?>
getRibbonRemainingPercentage() returns a String representing the percentage of ribbon remaining in the connected printer (will return 0 if there is no ribbon). Only the M611 and M710 support ribbons.
getSupplyColor() → Future<Color?>
getSupplyColor() returns a Color object representing the color of the supply installed in the connected printer (will return White color by default).
getSupplyHeight() → Future<double?>
getSupplyHeight() returns a String representing the height of the supply installed in the connected printer.
getSupplyName() → Future<String?>
getSupplyName() returns a String representing the supply installed in the connected printer.
getSupplyRemainingPercentage() → Future<int?>
getSupplyRemainingPercentage() returns a String representing the percentage of supply remaining in the connected printer
getSupplyWidth() → Future<double?>
getSupplyWidth() returns a String representing the width of the supply installed in the connected printer.
getTemplateData() → Future<Map<String, String>>
getTemplateData() returns a Map representing all objects on the current template. The maps keys representing the object name and its value is the type of object it is.
getTemplateSupplyName() → Future<String?>
getTemplateSupplyName() returns the name of the supply that used to design the selected template
getValidInkSupply() → Future<bool?>
getValidInkSupply() returns a boolean representing if the ink supply is valid.
getWifiVersion() → Future<String?>
getWifiVersion() returns a String representing the wifi version of the connected printer.
getYNumber() → Future<String?>
getYNumber() returns a String representing the unique Y Number of the installed supply.
isPreprintedSupply() → Future<bool?>
isPreprintedSupply() returns a boolean representing if the supply is pre-printed.
isRibbonValid() → Future<bool?>
isRibbonValid() returns a boolean representing if the ribbon is valid for the connected printer.
isSupplyValid() → Future<bool?>
isSupplyValid() returns a boolean representing if the supply is valid for the connected printer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(int copies, bool cutAfterEachLabel, bool isCollated, bool printTrailer) → Future<bool?>
print() asynchronously sends a print job of the currently set template to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
printAlignmentLabel() → Future<bool?>
printAlignmentLabel() asynchronously prints an alignment label from the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
printBitmapWithDimensions(double bitmapWidthInInches, double labelLengthInInches, int copies, bool cutAfterEachLabel, bool isCollated, bool printTrailer) → Future<bool?>
printBitmapWithDimensions() asynchronously sends a print job of the currently set template or bitmap image to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
printBitmapWithDimensionsAndRfid(double bitmapWidthInInches, double labelLengthInInches, List rfidOperations, int copies, String cutOption, bool isCollated, bool printTrailer) → Future<bool?>
printBitmapWithDimensionsAndRfid() asynchronously sends a print job of the currently set template or bitmap image with RFID operations to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
printPDF(String filePath, int rotationDegrees, int copies, String cutOption, bool isCollated, bool printTrailer) → Future<bool?>
printPDF() asynchronously sends a print job of the currently set PDF to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
printWithRfid(List rfidOperations, int copies, String cutOption, bool isCollated, bool printTrailer) → Future<bool?>
printWithRfid() asynchronously sends a print job with RFID operations to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
setAlignmentOffset(int offset) → Future<bool?>
setAlignmentOffset() asynchronously sets the alignment offset of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
setAutomaticShutoffTime(int minutes) → Future<bool?>
setAutomaticShutoffTime() asynchronously sets the automatic shutdown time of the printer in minutes and returns a Boolean value afterwards with the result of the setAutomaticShutoffTime operation (i.e. success or failure).
setMaintenanceStationProperty(String station) → Future<bool?>
setMaintenanceStationProperty() asynchronously sets the maintenance station property of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
setPlaceholderValue(String placeholder, String value) → Future<void>
setPlaceholderValue(String, String) takes two Strings to set a placeholder with a specified value.
setPrintQualityMode(String qualityMode) → Future<void>
setPrintQualityMode() asynchronously sets the print quality mode of the printer.
setSupplyDatabase(String filePath) → Future<void>
setSupplyDatabase(String) takes a file path (i.e. 'assets/PlatformDB.db') as a string representing a database file.
setTemplate(String filePath) → Future
setTemplate(String) takes a file path (i.e. 'assets/MyTemplate.BWT' or 'assets/MyImage.PNG') as a string representing a template file or image.
setTemplateWithBase64(String base64, bool isTemplate) → Future
setTemplateWithBase64(String, bool) takes a base64 string of data representing a template file and a boolean that tells the plugin if the file is a template.
startBlePrinterDiscovery() → void
startBlePrinterDiscovery() starts the Bluetooth scan for nearby Brady Printers. All of the details about these devices are stored internally and can be retrieved using the getPrinters() API method.
startWifiPrinterDiscovery() → void
startWifiPrinterDiscovery() starts the Wifi scan for nearby Brady Printers. All of the details about these devices are stored internally and can be retrieved using the getPrinters() API method.
stopPrinterDiscovery() → void
stopPrinterDiscovery() stops all discovery scans that were previously started.
suppliesMatch() → Future<bool?>
suppliesMatch() compares the supply name that is installed in the connected printer and the supply name that the current template was designed with. Returns true if the supplies match. Otherwise, returns false.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BradyFlutterPluginPlatform
The default instance of BradyFlutterPluginPlatform to use.
getter/setter pair