checkSupplyMismatch method

Future<bool?> checkSupplyMismatch()

checkSupplyMismatch() asynchronously checks if there is a supply mismatch in the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).

Implementation

Future<bool?> checkSupplyMismatch() {
  throw UnimplementedError('checkSupplyMismatch() has not been implemented.');
}