getIsSupplyDirectThermal method

Future<bool?> getIsSupplyDirectThermal()

getIsSupplyDirectThermal() returns a Boolean representing if the supply installed in the connected printer is direct thermal and will not have a separate ribbon.

Implementation

Future<bool?> getIsSupplyDirectThermal() async {
  throw UnimplementedError(
    'getIsSupplyDirectThermal() has not been implemented.',
  );
}