setMaintenanceStationProperty method

Future<bool?> setMaintenanceStationProperty(
  1. String station
)

setMaintenanceStationProperty() asynchronously sets the maintenance station property of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).

Implementation

Future<bool?> setMaintenanceStationProperty(String station) {
  throw UnimplementedError(
    'setMaintenanceStationProperty() has not been implemented.',
  );
}