printAlignmentLabel method
printAlignmentLabel() asynchronously prints an alignment label from the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
Implementation
@override
Future<bool?> printAlignmentLabel() async {
bool? printed = await methodChannel.invokeMethod<bool>(
'printAlignmentLabel',
);
return printed;
}