setMaintenanceStationProperty method
setMaintenanceStationProperty() asynchronously sets the maintenance station property of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
Implementation
@override
Future<bool?> setMaintenanceStationProperty(String station) async {
var sendMap = <String, dynamic>{"station": station};
bool? setResult = await methodChannel.invokeMethod<bool>(
'setMaintenanceStationProperty',
sendMap,
);
return setResult;
}