cleanPrinthead method
cleanPrinthead() asynchronously cleans the printhead of the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
Implementation
Future<bool?> cleanPrinthead() {
throw UnimplementedError('cleanPrinthead() has not been implemented.');
}