printAlignmentLabel method
printAlignmentLabel() asynchronously prints an alignment label from the connected printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
Implementation
Future<bool?> printAlignmentLabel() {
throw UnimplementedError('printAlignmentLabel() has not been implemented.');
}