printBitmapWithDimensionsAndRfid method
printBitmapWithDimensionsAndRfid() asynchronously sends a print job of the currently set template or bitmap image with RFID operations to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
Implementation
Future<bool?> printBitmapWithDimensionsAndRfid(
double bitmapWidthInInches,
double labelLengthInInches,
List<dynamic> rfidOperations,
int copies,
String cutOption,
bool isCollated,
bool printTrailer,
) {
throw UnimplementedError(
'printBitmapWithDimensionsAndRfid() has not been implemented.',
);
}