printPDF method
printPDF() asynchronously sends a print job of the currently set PDF to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
Implementation
Future<bool?> printPDF(
String filePath,
int rotationDegrees,
int copies,
String cutOption,
bool isCollated,
bool printTrailer,
) {
throw UnimplementedError('printPDF() has not been implemented.');
}