setAlignmentOffset method
setAlignmentOffset() asynchronously sets the alignment offset of the printer and returns a Boolean value afterwards with the result of the operation (i.e. success or failure).
Implementation
Future<bool?> setAlignmentOffset(int offset) {
throw UnimplementedError('setAlignmentOffset() has not been implemented.');
}